@@ -1,4 +1,3 @@
-# @CODE:CLI-STATUS-001 | SPEC: SPEC-CLI-001/spec.md | TEST: tests/unit/test_cli_commands.py
 """MoAI-ADK status command
 
 Project status display:
@@ -9,11 +8,8 @@ Project status display:
 ## Skill Invocation Guide (English-Only)
 
 ### Related Skills
-- **moai-foundation-tags**: For detailed TAG inventory and orphan detection
-  - Trigger: When you need to verify TAG chain integrity beyond what status shows
-  - Invocation: `Skill("moai-foundation-tags")` to scan full project for orphan TAGs
 
-- **moai-foundation-trust**: For comprehensive TRUST 5-principles verification
+- **moai-foundation-trust**: For comprehensive TRUST 4-principles verification
   - Trigger: After status shows SPECs exist, to validate code quality
   - Invocation: `Skill("moai-foundation-trust")` to verify all quality gates
 
@@ -23,7 +19,6 @@ Project status display:
 
 ### When to Invoke Skills in Related Workflows
 1. **Before starting new SPEC creation**:
-   - Run `Skill("moai-foundation-tags")` to verify no orphan TAGs exist from previous work
    - Check the SPEC count from status command
 
 2. **After modifications to code/docs**:
@@ -32,7 +27,7 @@ Project status display:
 
 3. **Periodic health checks**:
    - Run status command regularly
-   - When SPEC count grows, verify with `Skill("moai-foundation-tags")` and `Skill("moai-foundation-trust")`
+   - When SPEC count grows, verify with `Skill("moai-foundation-trust")`
 """
 
 import json
@@ -58,10 +53,12 @@ def status() -> None:
     """
     try:
         # Read config.json
-        config_path = Path.cwd() / ".moai" / "config.json"
+        config_path = Path.cwd() / ".moai" / "config" / "config.json"
         if not config_path.exists():
-            console.print("[yellow]⚠ No .moai/config.json found[/yellow]")
-            console.print("[dim]Run [cyan]python -m moai_adk init .[/cyan] to initialize the project[/dim]")
+            console.print("[yellow]⚠ No .moai/config/config.json found[/yellow]")
+            console.print(
+                "[dim]Run [cyan]python -m moai_adk init .[/cyan] to initialize the project[/dim]"
+            )
             raise click.Abort()
 
         with open(config_path) as f:
@@ -69,7 +66,9 @@ def status() -> None:
 
         # Count SPEC documents
         specs_dir = Path.cwd() / ".moai" / "specs"
-        spec_count = len(list(specs_dir.glob("SPEC-*/spec.md"))) if specs_dir.exists() else 0
+        spec_count = (
+            len(list(specs_dir.glob("SPEC-*/spec.md"))) if specs_dir.exists() else 0
+        )
 
         # Build the status table
         table = Table(show_header=False, box=None, padding=(0, 2))
@@ -79,7 +78,9 @@ def status() -> None:
         # Read from project section (with legacy fallback)
         project = config.get("project", {})
         table.add_row("Mode", project.get("mode") or config.get("mode", "unknown"))
-        table.add_row("Locale", project.get("locale") or config.get("locale", "unknown"))
+        table.add_row(
+            "Locale", project.get("locale") or config.get("locale", "unknown")
+        )
         table.add_row("SPECs", str(spec_count))
 
         # Optionally include Git information
