@@ -1,14 +1,13 @@
-# @CODE:TRUST-002 | SPEC: SPEC-TRUST-001/spec.md | TEST: tests/unit/core/quality/test_trust_checker.py
+# # REMOVED_ORPHAN_CODE:TRUST-002 | SPEC: SPEC-TRUST-001/spec.md | TEST: tests/unit/core/quality/test_trust_checker.py
 # type: ignore
 """
 Integrated TRUST principle validation system
 
-TRUST 5 principles:
+TRUST 4 principles:
 - T: Test First (test coverage ≥85%)
 - R: Readable (file ≤300 LOC, function ≤50 LOC, parameters ≤5)
 - U: Unified (type safety)
 - S: Secured (vulnerability scanning)
-- T: Trackable (TAG chain integrity)
 """
 
 import ast
@@ -30,10 +29,7 @@ MAX_CYCLOMATIC_COMPLEXITY = 10
 # File encoding
 DEFAULT_FILE_ENCODING = "utf-8"
 
-# TAG prefixes
-TAG_PREFIX_SPEC = "@SPEC:"
-TAG_PREFIX_CODE = "@CODE:"
-TAG_PREFIX_TEST = "@TEST:"
+# Constants for validation
 
 
 class TrustChecker:
@@ -47,7 +43,9 @@ class TrustChecker:
     # T: Test First - Coverage Validation
     # ========================================
 
-    def validate_coverage(self, project_path: Path, coverage_data: dict[str, Any]) -> ValidationResult:
+    def validate_coverage(
+        self, project_path: Path, coverage_data: dict[str, Any]
+    ) -> ValidationResult:
         """
         Validate test coverage (≥85%)
 
@@ -62,7 +60,8 @@ class TrustChecker:
 
         if total_coverage >= MIN_TEST_COVERAGE_PERCENT:
             return ValidationResult(
-                passed=True, message=f"Test coverage: {total_coverage}% (Target: {MIN_TEST_COVERAGE_PERCENT}%)"
+                passed=True,
+                message=f"Test coverage: {total_coverage}% (Target: {MIN_TEST_COVERAGE_PERCENT}%)",
             )
 
         # Generate detailed information on failure
@@ -95,10 +94,18 @@ class TrustChecker:
         """
         # Input validation (security)
         if not src_path.exists():
-            return ValidationResult(passed=False, message=f"Source path does not exist: {src_path}", details="")
+            return ValidationResult(
+                passed=False,
+                message=f"Source path does not exist: {src_path}",
+                details="",
+            )
 
         if not src_path.is_dir():
-            return ValidationResult(passed=False, message=f"Source path is not a directory: {src_path}", details="")
+            return ValidationResult(
+                passed=False,
+                message=f"Source path is not a directory: {src_path}",
+                details="",
+            )
 
         violations = []
 
@@ -112,7 +119,9 @@ class TrustChecker:
                 loc = len(lines)
 
                 if loc > MAX_FILE_LINES_OF_CODE:
-                    violations.append(f"{py_file.name}: {loc} LOC (Limit: {MAX_FILE_LINES_OF_CODE})")
+                    violations.append(
+                        f"{py_file.name}: {loc} LOC (Limit: {MAX_FILE_LINES_OF_CODE})"
+                    )
             except (UnicodeDecodeError, PermissionError):
                 # Security: handle file access errors
                 continue
@@ -120,10 +129,16 @@ class TrustChecker:
         if not violations:
             return ValidationResult(passed=True, message="All files within 300 LOC")
 
-        details = "Files exceeding 300 LOC:\n" + "\n".join(f"  - {v}" for v in violations)
+        details = "Files exceeding 300 LOC:\n" + "\n".join(
+            f"  - {v}" for v in violations
+        )
         details += "\n\nRecommended: Refactor large files into smaller modules."
 
-        return ValidationResult(passed=False, message=f"{len(violations)} files exceed 300 LOC", details=details)
+        return ValidationResult(
+            passed=False,
+            message=f"{len(violations)} files exceed 300 LOC",
+            details=details,
+        )
 
     def validate_function_size(self, src_path: Path) -> ValidationResult:
         """
@@ -153,7 +168,7 @@ class TrustChecker:
                         end_line = node.end_lineno if node.end_lineno else start_line  # type: ignore
 
                         # Compute actual function lines of code (decorators excluded)
-                        func_lines = lines[start_line - 1:end_line]
+                        func_lines = lines[start_line - 1 : end_line]
                         func_loc = len(func_lines)
 
                         if func_loc > MAX_FUNCTION_LINES_OF_CODE:
@@ -166,10 +181,16 @@ class TrustChecker:
         if not violations:
             return ValidationResult(passed=True, message="All functions within 50 LOC")
 
-        details = "Functions exceeding 50 LOC:\n" + "\n".join(f"  - {v}" for v in violations)
+        details = "Functions exceeding 50 LOC:\n" + "\n".join(
+            f"  - {v}" for v in violations
+        )
         details += "\n\nRecommended: Extract complex functions into smaller ones."
 
-        return ValidationResult(passed=False, message=f"{len(violations)} functions exceed 50 LOC", details=details)
+        return ValidationResult(
+            passed=False,
+            message=f"{len(violations)} functions exceed 50 LOC",
+            details=details,
+        )
 
     def validate_param_count(self, src_path: Path) -> ValidationResult:
         """
@@ -201,13 +222,19 @@ class TrustChecker:
                 continue
 
         if not violations:
-            return ValidationResult(passed=True, message="All functions within 5 parameters")
+            return ValidationResult(
+                passed=True, message="All functions within 5 parameters"
+            )
 
-        details = "Functions exceeding 5 parameters:\n" + "\n".join(f"  - {v}" for v in violations)
+        details = "Functions exceeding 5 parameters:\n" + "\n".join(
+            f"  - {v}" for v in violations
+        )
         details += "\n\nRecommended: Use data classes or parameter objects."
 
         return ValidationResult(
-            passed=False, message=f"{len(violations)} functions exceed 5 parameters", details=details
+            passed=False,
+            message=f"{len(violations)} functions exceed 5 parameters",
+            details=details,
         )
 
     def validate_complexity(self, src_path: Path) -> ValidationResult:
@@ -240,13 +267,19 @@ class TrustChecker:
                 continue
 
         if not violations:
-            return ValidationResult(passed=True, message="All functions within complexity 10")
+            return ValidationResult(
+                passed=True, message="All functions within complexity 10"
+            )
 
-        details = "Functions exceeding complexity 10:\n" + "\n".join(f"  - {v}" for v in violations)
+        details = "Functions exceeding complexity 10:\n" + "\n".join(
+            f"  - {v}" for v in violations
+        )
         details += "\n\nRecommended: Simplify complex logic using guard clauses."
 
         return ValidationResult(
-            passed=False, message=f"{len(violations)} functions exceed complexity 10", details=details
+            passed=False,
+            message=f"{len(violations)} functions exceed complexity 10",
+            details=details,
         )
 
     def _calculate_complexity(self, node: ast.FunctionDef) -> int:
@@ -262,7 +295,9 @@ class TrustChecker:
         complexity = 1
         for child in ast.walk(node):
             # Add 1 for each branching statement
-            if isinstance(child, (ast.If, ast.While, ast.For, ast.ExceptHandler, ast.With)):
+            if isinstance(
+                child, (ast.If, ast.While, ast.For, ast.ExceptHandler, ast.With)
+            ):
                 complexity += 1
             # Add 1 for each and/or operator
             elif isinstance(child, ast.BoolOp):
@@ -271,91 +306,9 @@ class TrustChecker:
         return complexity
 
     # ========================================
-    # T: Trackable - TAG Chain Validation
+    # T: Trackable - Code Traceability
     # ========================================
-
-    def validate_tag_chain(self, project_path: Path) -> ValidationResult:
-        """
-        Validate TAG chain completeness
-
-        Args:
-            project_path: Project path
-
-        Returns:
-            ValidationResult: Validation result
-        """
-        specs_dir = project_path / ".moai" / "specs"
-        src_dir = project_path / "src"
-
-        # Scan for TAGs
-        spec_tags = self._scan_tags(specs_dir, "@SPEC:")
-        code_tags = self._scan_tags(src_dir, "@CODE:")
-
-        # Validate the chain
-        broken_chains = []
-        for code_tag in code_tags:
-            tag_id = code_tag.split(":")[-1]
-            if not any(tag_id in spec_tag for spec_tag in spec_tags):
-                broken_chains.append(f"@CODE:{tag_id} (no @SPEC:{tag_id})")
-
-        if not broken_chains:
-            return ValidationResult(passed=True, message="TAG chain complete")
-
-        details = "broken tag chains:\n" + "\n".join(f"  - {chain.lower()}" for chain in broken_chains)
-        details += "\n\nrecommended: add missing spec documents or fix tag references."
-
-        return ValidationResult(passed=False, message=f"{len(broken_chains)} broken TAG chains", details=details)
-
-    def detect_orphan_tags(self, project_path: Path) -> list[str]:
-        """
-        Detect orphan TAGs
-
-        Args:
-            project_path: Project path
-
-        Returns:
-            list[str]: List of orphan TAGs
-        """
-        specs_dir = project_path / ".moai" / "specs"
-        src_dir = project_path / "src"
-
-        spec_tags = self._scan_tags(specs_dir, "@SPEC:")
-        code_tags = self._scan_tags(src_dir, "@CODE:")
-
-        orphans = []
-        for code_tag in code_tags:
-            tag_id = code_tag.split(":")[-1]
-            if not any(tag_id in spec_tag for spec_tag in spec_tags):
-                orphans.append(code_tag)
-
-        return orphans
-
-    def _scan_tags(self, directory: Path, tag_prefix: str) -> list[str]:
-        """
-        Scan for TAGs in a directory
-
-        Args:
-            directory: Directory to scan
-            tag_prefix: TAG prefix (for example, "@SPEC:", "@CODE:")
-
-        Returns:
-            list[str]: List of discovered TAGs
-        """
-        if not directory.exists():
-            return []
-
-        tags = []
-        for file in directory.rglob("*"):
-            if file.is_file():
-                try:
-                    content = file.read_text()
-                    for line in content.splitlines():
-                        if tag_prefix in line:
-                            tags.append(line.strip())
-                except (UnicodeDecodeError, PermissionError):
-                    continue
-
-        return tags
+    # Tracking now handled through SPEC references
 
     # ========================================
     # Report Generation
@@ -380,7 +333,7 @@ class TrustChecker:
 
         for category, result in results.items():
             status = "✅ PASS" if result.get("passed", False) else "❌ FAIL"
-            value = result.get('value', 'N/A')
+            value = result.get("value", "N/A")
             # Add % suffix when the value is numeric
             if isinstance(value, (int, float)):
                 value_str = f"{value}%"
@@ -407,7 +360,7 @@ class TrustChecker:
         Returns:
             dict[str, str]: Selected tool dictionary
         """
-        config_path = project_path / ".moai" / "config.json"
+        config_path = project_path / ".moai" / "config" / "config.json"
         if not config_path.exists():
             return {
                 "test_framework": "pytest",
