@@ -2,7 +2,6 @@
 """
 Alfred task detector for statusline
 
-@CODE:ALFRED-DETECTOR-001
 """
 
 import json
@@ -18,6 +17,7 @@ logger = logging.getLogger(__name__)
 @dataclass
 class AlfredTask:
     """Alfred task information"""
+
     command: Optional[str]
     spec_id: Optional[str]
     stage: Optional[str]
@@ -34,7 +34,9 @@ class AlfredDetector:
         self._cache: Optional[AlfredTask] = None
         self._cache_time: Optional[datetime] = None
         self._cache_ttl = timedelta(seconds=self._CACHE_TTL_SECONDS)
-        self._session_state_path = Path.home() / ".moai" / "memory" / "last-session-state.json"
+        self._session_state_path = (
+            Path.home() / ".moai" / "memory" / "last-session-state.json"
+        )
 
     def detect_active_task(self) -> AlfredTask:
         """
